@@ -257,16 +257,15 @@ IBClient <- R6Class("IBClient",
 
       payload <- contract[c(1L:12L, 14L, 15L)]
 
-      payload <- c(payload, order[4L:9L])       # "action" through "tif"
+      payload <- c(payload, order[4L:9L]) # "action" -> "tif"
 
-      # Extended order fields
       payload <- c(payload, order[c("ocaGroup",
                                     "account",
                                     "openClose")],
 
                             map_enum2int("Origin", order$origin),
 
-                            order[14L:22L])     # "orderRef" through "hidden"
+                            order[14L:22L]) # "orderRef" -> "hidden"
 
       if(contract$secType == "BAG") {
 
@@ -287,15 +286,18 @@ IBClient <- R6Class("IBClient",
                      pack_tagvalue(order$smartComboRoutingParams, mode="unfold"))
       }
 
-      payload <- c(payload, "",       # Deprecated sharesAllocation
+      payload <- c(payload, "", # Deprecated sharesAllocation
+
                             order[c("discretionaryAmt",
                                     "goodAfterTime",
                                     "goodTillDate",
                                     "faGroup",
                                     "faMethod",
-                                    "faPercentage",
-                                    "faProfile",
-                                    "modelCode",
+                                    "faPercentage")],
+
+      if(self$serVersion < MIN_SERVER_VER_FA_PROFILE_DESUPPORT) "", # Deprecated faProfile
+
+                            order[c("modelCode",
                                     "shortSaleSlot",
                                     "designatedLocation",
                                     "exemptCode",
@@ -306,9 +308,9 @@ IBClient <- R6Class("IBClient",
                                     "minQty",
                                     "percentOffset")],
 
-                            FALSE,    # Deprecated eTradeOnly
-                            FALSE,    # Deprecated firmQuoteOnly
-                            "",       # Deprecated nbboPriceCap
+                            FALSE, # Deprecated eTradeOnly
+                            FALSE, # Deprecated firmQuoteOnly
+                            "",    # Deprecated nbboPriceCap
 
                             map_enum2int("AuctionStrategy", order$auctionStrategy),
 
@@ -324,7 +326,7 @@ IBClient <- R6Class("IBClient",
                                     "deltaNeutralAuxPrice")])
 
       if(nzchar(order$deltaNeutralOrderType, keepNA=TRUE))
-        payload <- c(payload, order[58L:65L])
+        payload <- c(payload, order[54L:61L]) # "deltaNeutralConId" -> "deltaNeutralDesignatedLocation"
 
       payload <- c(payload, order[c("continuousUpdate",
                                     "referencePriceType",
@@ -335,7 +337,7 @@ IBClient <- R6Class("IBClient",
                                     "scalePriceIncrement")])
 
       if(!is.na(order$scalePriceIncrement) && order$scalePriceIncrement > 0)
-        payload <- c(payload, order[73L:79L])
+        payload <- c(payload, order[69L:75L]) # "scalePriceAdjustValue" -> "scaleRandomPercent"
 
       payload <- c(payload, order[c("scaleTable",
                                     "activeStartTime",
@@ -410,26 +412,22 @@ IBClient <- R6Class("IBClient",
                                     "usePriceMgmtAlgo",
                                     "duration",
                                     "postToAts",
-                                    "autoCancelParent")])
+                                    "autoCancelParent",
+                                    "advancedErrorOverride",
+                                    "manualOrderTime")])
 
-      if(self$serVersion >= MIN_SERVER_VER_ADVANCED_ORDER_REJECT)
-        payload <- c(payload, order$advancedErrorOverride)
+      if(contract$exchange == "IBKRATS")
+        payload <- c(payload, order$minTradeQty)
 
-      if(self$serVersion >= MIN_SERVER_VER_MANUAL_ORDER_TIME)
-        payload <- c(payload, order$manualOrderTime)
+      if(order$orderType == "PEG BEST")
+        payload <- c(payload, order[c("minCompeteSize",
+                                      "competeAgainstBestOffset")])
 
-      if(self$serVersion >= MIN_SERVER_VER_PEGBEST_PEGMID_OFFSETS) {
+      if(order$orderType == "PEG BEST" && order$competeAgainstBestOffset == Inf ||
+         order$orderType == "PEG MID")
+        payload <- c(payload, order[c("midOffsetAtWhole",
+                                      "midOffsetAtHalf")])
 
-        if(contract$exchange == "IBKRATS")
-          payload <- c(payload, order$minTradeQty)
-
-        if(order$orderType == "PEG BEST")
-          payload <- c(payload, order[c("minCompeteSize", "competeAgainstBestOffset")])
-
-        if(order$orderType == "PEG BEST" && order$competeAgainstBestOffset == Inf ||
-           order$orderType == "PEG MID")
-          payload <- c(payload, order[c("midOffsetAtWhole", "midOffsetAtHalf")])
-      }
 
       msg <- c(msg, id, private$sanitize(payload))
 
@@ -440,7 +438,7 @@ IBClient <- R6Class("IBClient",
 
       msg <- c("4", "1", ### CANCEL_ORDER
                id,
-               if(self$serVersion >= MIN_SERVER_VER_MANUAL_ORDER_TIME) manualOrderCancelTime)
+               manualOrderCancelTime)
 
       private$encodeMsg(msg)
     },
@@ -473,7 +471,7 @@ IBClient <- R6Class("IBClient",
       msg <- c("9", "8", ### REQ_CONTRACT_DATA
                reqId,
                private$sanitize(contract[1L:15L]),
-               if(self$serVersion >= MIN_SERVER_VER_BOND_ISSUERID) contract$issuerId)
+               contract$issuerId)
 
       private$encodeMsg(msg)
     },
@@ -856,12 +854,7 @@ IBClient <- R6Class("IBClient",
 
       msg <- c("102", ### REQ_WSH_EVENT_DATA
                reqId,
-               if(self$serVersion >= MIN_SERVER_VER_WSH_EVENT_DATA_FILTERS_DATE)
-                 private$sanitize(wshEventData)
-               else if(self$serVersion >= MIN_SERVER_VER_WSH_EVENT_DATA_FILTERS)
-                 private$sanitize(wshEventData[1L:5L])
-               else
-                 wshEventData$conId)
+               private$sanitize(wshEventData))
 
       private$encodeMsg(msg)
     },
